@@ -8,7 +8,7 @@ use base qw( Exporter );
 our @EXPORT = grep /^arguments_/, keys %FFI::Platypus::API::;
 
 # ABSTRACT: Platypus arguments and return value API for custom types
-our $VERSION = '0.96'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 1;
@@ -25,7 +25,7 @@ FFI::Platypus::API - Platypus arguments and return value API for custom types
 
 =head1 VERSION
 
-version 0.96
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -268,6 +268,10 @@ Mohammad S Anwar (MANWAR)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
