@@ -6,7 +6,7 @@ use Carp ();
 use FFI::Platypus;
 
 # ABSTRACT: Declarative interface to FFI::Platypus
-our $VERSION = '0.96'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 our $ffi    = {};
@@ -174,7 +174,7 @@ FFI::Platypus::Declare - Declarative interface to FFI::Platypus
 
 =head1 VERSION
 
-version 0.96
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -456,6 +456,10 @@ Mohammad S Anwar (MANWAR)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
