@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Documentation and tools for using Platypus with the Assembly
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 sub native_type_map
@@ -26,12 +26,12 @@ FFI::Platypus::Lang::ASM - Documentation and tools for using Platypus with the A
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('ASM');
 
 =head1 DESCRIPTION
@@ -91,6 +91,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
