@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Documentation and tools for using Platypus with the C programming language
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 sub native_type_map
@@ -27,19 +27,19 @@ FFI::Platypus::Lang::C - Documentation and tools for using Platypus with the C p
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('C'); # the default
 
 =head1 DESCRIPTION
 
-This module provides some hooks for Platypus to interact with the C 
-programming language.  It is generally used by default if you do not 
-specify another foreign programming language with the 
+This module provides some hooks for Platypus to interact with the C
+programming language.  It is generally used by default if you do not
+specify another foreign programming language with the
 L<FFI::Platypus#lang> attribute.
 
 =head1 METHODS
@@ -88,6 +88,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
