@@ -5,7 +5,7 @@ use warnings;
 use Config;
 
 # ABSTRACT: Documentation and tools for using Platypus with the Windows API
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 sub abi
@@ -24,7 +24,7 @@ sub native_type_map
   {
     require FFI::Platypus::ShareConfig;
     %map = %{ FFI::Platypus::ShareConfig->get('type_map') };
-    
+
     my %win32_map = qw(
       BOOL                      int
       BOOLEAN                   BYTE
@@ -114,9 +114,9 @@ sub native_type_map
       VOID                      void
       WORD                      uint16
       WPARAM                    UINT_PTR
-      
+
     );
-    
+
     if($Config{ptrsize} == 4)
     {
       $win32_map{HALF_PTR}  = 'sint16';
@@ -139,7 +139,7 @@ sub native_type_map
     {
       die "interesting word size you have";
     }
-    
+
     foreach my $alias (keys %win32_map)
     {
       my $type = $alias;
@@ -163,12 +163,12 @@ sub native_type_map
         die "unable to resolve $alias => ... => $type";
       }
     }
-    
+
     # stuff we are not yet dealing with
     # LPCTSTR is unicode string, not currently supported
     # LPWSTR 16 bit unicode string
     # TBYTE TCHAR UNICODE_STRING WCHAR
-    # Not supported: POINTER_32 POINTER_64 POINTER_SIGNED POINTER_UNSIGNED    
+    # Not supported: POINTER_32 POINTER_64 POINTER_SIGNED POINTER_UNSIGNED
   }
   \%map;
 }
@@ -187,18 +187,18 @@ FFI::Platypus::Lang::Win32 - Documentation and tools for using Platypus with the
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Win32');
 
 =head1 DESCRIPTION
 
-This module provides the Windows datatypes used by the Windows API.  
-This means that you can use things like C<DWORD> as an alias for 
+This module provides the Windows datatypes used by the Windows API.
+This means that you can use things like C<DWORD> as an alias for
 C<uint32>.
 
 =head1 METHODS
@@ -251,6 +251,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
