@@ -7,20 +7,62 @@ use FFI::Platypus;
 use base qw( Exporter );
 use constant 1.32 ();
 
-our @EXPORT = qw( record_layout );
+our @EXPORT = qw( record_layout record_layout_1 );
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
+
+
+sub record_layout_1
+{
+  if(@_ % 2 == 0)
+  {
+    my $ffi = FFI::Platypus->new( api => 1 );
+    unshift @_, $ffi;
+    goto &record_layout;
+  }
+  elsif(defined $_[0] && ref($_[0]) eq 'ARRAY')
+  {
+    my @args = @{ shift @_ };
+    unshift @args, api => 1;
+    unshift @_, \@args;
+    goto &record_layout;
+  }
+  elsif(defined $_[0] && eval { $_[0]->isa('FFI::Platypus') })
+  {
+    goto &record_layout;
+  }
+  else
+  {
+    croak "odd number of arguments, but first argument is not either an array reference or Platypus instance";
+  }
+}
 
 
 sub record_layout
 {
-  my $ffi = ref($_[0]) ? shift : FFI::Platypus->new;
+  my $ffi;
+
+  if(defined $_[0])
+  {
+    if(ref($_[0]) eq 'ARRAY')
+    {
+      my @args = @{ shift() };
+      $ffi = FFI::Platypus->new(@args);
+    }
+    elsif(eval { $_[0]->isa('FFI::Platypus') })
+    {
+      $ffi = shift;
+    }
+  }
+
+  $ffi ||= FFI::Platypus->new;
+
   my $offset = 0;
   my $record_align = 0;
-  
+
   croak "uneven number of arguments!" if scalar(@_) % 2;
-  
+
   my($caller, $filename, $line) = caller;
 
   if($caller->can("_ffi_record_size")
@@ -28,26 +70,46 @@ sub record_layout
   {
     croak "record already defined for the class $caller";
   }
-  
+
   my @destroy;
-  
+  my @ffi_types;
+
   while(@_)
   {
-    my $type = shift;
+    my $spec = shift;
     my $name = shift;
-    
+    my $type = $ffi->{tp}->parse( $spec, { member => 1 } );
+
     croak "illegal name $name"
       unless $name =~ /^[A-Za-z_][A-Za-z_0-9]*$/
       ||     $name eq ':';
     croak "accessor/method $name already exists"
       if $caller->can($name);
-    
-    my $size  = $ffi->sizeof($type);
-    my $align = $ffi->alignof($type);
-    $record_align = $align if $align > $record_align;
-    my $meta  = $ffi->type_meta($type);
 
-    $offset++ while $offset % $align;    
+    my $size  = $type->sizeof;
+    my $align = $type->alignof;
+    $record_align = $align if $align > $record_align;
+    my $meta  = $type->meta;
+
+    $offset++ while $offset % $align;
+
+    {
+      my $count;
+      my $ffi_type;
+
+      if($meta->{type} eq 'record') # this means fixed string atm
+      {
+        $ffi_type = 'sint8';
+        $count = $size;
+      }
+      else
+      {
+        $ffi_type = $meta->{ffi_type};
+        $count    = $meta->{element_count};
+        $count    = 1 unless defined $count;
+      }
+      push @ffi_types, $ffi_type for 1..$count;
+    }
 
     if($name ne ':')
     {
@@ -67,16 +129,16 @@ sub record_layout
       my $error_str = _accessor
         $full_name,
         "$filename:$line",
-        $ffi->_type_lookup($type),
+        $type,
         $offset;
-      croak("$error_str ($type $name)") if $error_str;
+      croak("$error_str ($spec $name)") if $error_str;
     };
-    
+
     $offset += $size;
   }
-  
+
   my $size = $offset;
-  
+
   no strict 'refs';
   constant->import("${caller}::_ffi_record_size", $size);
   constant->import("${caller}::_ffi_record_align", $record_align);
@@ -88,19 +150,27 @@ sub record_layout
       if @$args % 2;
     my $record = "\0" x $class->_ffi_record_size;
     my $self = bless \$record, $class;
-    
+
     while(@$args)
     {
       my $key = shift @$args;
       my $value = shift @$args;
       $self->$key($value);
     }
-    
+
     $self;
   };
-  
+
+  {
+    require FFI::Platypus::Record::Meta;
+    my $ffi_meta = FFI::Platypus::Record::Meta->new(
+      \@ffi_types,
+    );
+    *{join '::', $caller, '_ffi_meta'} = sub { $ffi_meta };
+  }
+
   my $destroy_sub = sub {};
-  
+
   if(@destroy)
   {
     $destroy_sub = sub {
@@ -129,7 +199,7 @@ FFI::Platypus::Record - FFI support for structured records data
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -152,7 +222,7 @@ Perl:
  
  use FFI::Platypus::Record;
  
- record_layout(qw(
+ record_layout_1(qw(
    int       age
    string(3) title
    string_rw name
@@ -162,7 +232,7 @@ Perl:
  
  use FFI::Platypus;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lib("myperson.so");
  $ffi->type("record(MyPerson)" => 'MyPerson');
  
@@ -172,7 +242,7 @@ Perl:
    name  => "John Smith",
  );
  
- $ffi->attach( process_person => [ 'MyPerson' ] => 'void' );
+ $ffi->attach( process_person => [ 'MyPerson*' ] => 'void' );
  
  process_person($person);
  
@@ -184,38 +254,54 @@ Perl:
 
 [version 0.21]
 
-This module provides a mechanism for building classes that can be used 
-to mange structured data records (known as C as "structs" and in some 
-languages as "records").  A structured record is a series of bytes that 
-have structure understood by the C or other foreign language library 
-that you are interfacing with.  It is designed for use with FFI and 
+This module provides a mechanism for building classes that can be used
+to mange structured data records (known as C as "structs" and in some
+languages as "records").  A structured record is a series of bytes that
+have structure understood by the C or other foreign language library
+that you are interfacing with.  It is designed for use with FFI and
 L<FFI::Platypus>, though it may have other applications.
 
 =head1 FUNCTIONS
 
-=head2 record_layout
+=head2 record_layout_1
 
- record_layout($ffi, $type => $name, ... );
- record_layout($type => $name, ... );
+ record_layout_1($ffi, $type => $name, ... );
+ record_layout_1(\@ffi_args, $type => $name, ... );
+ record_layout_1($type => $name, ... );
 
-Define the layout of the record.  You may optionally provide an instance 
-of L<FFI::Platypus> as the first argument in order to use its type 
-aliases.  Then you provide members as type/name pairs.
+Define the layout of the record.  You may optionally provide an instance
+of L<FFI::Platypus> as the first argument in order to use its type
+aliases.  Alternatively you may provide constructor arguments that will
+be passed to the internal platypus instance.  Thus this is the same:
 
-For each member you declare, C<record_layout> will create an accessor 
-which can be used to read and write its value. For example imagine a 
+ my $ffi = FFI::Platypus->new( lang => 'Rust', api => 1 );
+ record_layout_1( $ffi, ... );
+ # same as:
+ record_layout_1( [ lang => 'Rust' ], ... );
+
+and this is the same:
+
+ my $ffi = FFI::Platypus->new( api => 1 );
+ record_layout_1( $ffi, ... );
+ # same as:
+ record_layout_1( ... );
+
+Then you provide members as type/name pairs.
+
+For each member you declare, C<record_layout_1> will create an accessor
+which can be used to read and write its value. For example imagine a
 class C<Foo>:
 
  package Foo;
  
  use FFI::Platypus::Record;
  
- record_layout(
+ record_layout_1(
    int          => 'bar',  #  int bar;
    'string(10)' => 'baz',  #  char baz[10];
  );
 
-You can get and set its fields with like named C<bar> and C<baz> 
+You can get and set its fields with like named C<bar> and C<baz>
 accessors:
 
  my $foo = Foo->new;
@@ -226,7 +312,7 @@ accessors:
  $foo->baz("grimlock\0\0"); # should be 10 characters long
  my $string_value = $foo->baz; # includes the trailing \0\0
 
-You can also pass initial values in to the constructor, either passing 
+You can also pass initial values in to the constructor, either passing
 as a list of key value pairs or by passing a hash reference:
 
  $foo = Foo->new(
@@ -241,30 +327,30 @@ as a list of key value pairs or by passing a hash reference:
    baz => "grimlock\0\0",
  } );
 
-If there are members of a record that you need to account for in terms 
-of size and alignment, but do not want to have an accessor for, you can 
+If there are members of a record that you need to account for in terms
+of size and alignment, but do not want to have an accessor for, you can
 use C<:> as a place holder for its name:
 
- record_layout(
+ record_layout_1(
    'int'        => ':',
    'string(10)' => 'baz',
  );
 
 =head3 strings
 
-So far I've shown fixed length strings.  These are declared with the 
-word C<string> followed by the length of the string in parentheticals.  
-Fixed length strings are included inside the record itself and do not 
-need to be allocated or deallocated separately from the record.  
-Variable length strings must be allocated on the heap, and thus require 
-a sense of "ownership", that is whomever allocates variable length 
-strings should be responsible for also free'ing them.  To handle this, 
-you can add a C<ro> or C<rw> trait to a string field.  The default is 
+So far I've shown fixed length strings.  These are declared with the
+word C<string> followed by the length of the string in parentheticals.
+Fixed length strings are included inside the record itself and do not
+need to be allocated or deallocated separately from the record.
+Variable length strings must be allocated on the heap, and thus require
+a sense of "ownership", that is whomever allocates variable length
+strings should be responsible for also free'ing them.  To handle this,
+you can add a C<ro> or C<rw> trait to a string field.  The default is
 C<ro>, means that you can get, but not set its value:
 
  package Foo;
  
- record_layout(
+ record_layout_1(
    'string ro' => 'bar',  # same type as 'string' and 'string_ro'
  );
  
@@ -279,7 +365,7 @@ If you specify a field is C<rw>, then you can set its value:
 
  package Foo;
  
- record_layout(
+ record_layout_1(
    'string rw' => 'bar',  # same type as 'string_rw'
  );
  
@@ -290,10 +376,10 @@ If you specify a field is C<rw>, then you can set its value:
  my $string = $foo->bar;  # GOOD
  $foo->bar("starscream"); # GOOD
 
-Any string value that is pointed to by the record will be free'd when it 
-falls out of scope, so you must be very careful that any C<string rw> 
-fields are not set or modified by C code.  You should also take care not 
-to copy any record that has a C<rw> string in it because its values will 
+Any string value that is pointed to by the record will be free'd when it
+falls out of scope, so you must be very careful that any C<string rw>
+fields are not set or modified by C code.  You should also take care not
+to copy any record that has a C<rw> string in it because its values will
 be free'd twice!
 
  use Clone qw( clone );
@@ -306,7 +392,7 @@ Arrays of integer, floating points and opaque pointers are supported.
 
  package Foo;
  
- record_layout(
+ record_layout_1(
    'int[10]' => 'bar',
  );
  
@@ -318,6 +404,16 @@ Arrays of integer, floating points and opaque pointers are supported.
  $foo->bar(5, -6); # sets the 5th element in the array to -6
  my $item = $foo->bar(5); gets the 5th element in the array
 
+=head2 record_layout
+
+ record_layout($ffi, $type => $name, ... );
+ record_layout(\@ffi_args, $type => $name, ... );
+ record_layout($type => $name, ... );
+
+This function works like C<record_layout> except that
+C<api =E<gt> 0> is used instead of C<api =E<gt> 1>.
+All new code should use C<record_layout_1> instead.
+
 =head1 TODO
 
 These useful features (and probably more) are missing:
@@ -348,7 +444,7 @@ Another method for constructing and dissecting structured data records.
 
 =item L<pack and unpack|perlpacktut>
 
-Built-in Perl functions for constructing and dissecting structured data 
+Built-in Perl functions for constructing and dissecting structured data
 records.
 
 =back
@@ -379,6 +475,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
