@@ -5,12 +5,12 @@ use warnings;
 use Carp qw( croak );
 
 # ABSTRACT: Tied array interface for record array members
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 sub TIEARRAY
 {
-  my $class = shift;  
+  my $class = shift;
   bless [ @_ ], $class;
 }
 
@@ -38,7 +38,7 @@ sub CLEAR
 {
   my($self) = @_;
   my($obj, $member) = @$self;
-  
+
   $obj->$member([]);
 }
 
@@ -62,7 +62,7 @@ FFI::Platypus::Record::TieArray - Tied array interface for record array members
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -79,7 +79,7 @@ version 0.83
  {
    my($self, $arg) = @_;
    $self->_bar($arg) if ref($arg) eq ' ARRAY';
-   tie my @list, 'FFI::Platypus::Record::TieArray', 
+   tie my @list, 'FFI::Platypus::Record::TieArray',
      $self, '_bar', 20;
  }
  
@@ -94,13 +94,13 @@ version 0.83
 
 =head1 DESCRIPTION
 
-B<WARNING>: This module is considered EXPERIMENTAL.  It may go away or 
-be changed in incompatible ways, possibly without notice, but not 
+B<WARNING>: This module is considered EXPERIMENTAL.  It may go away or
+be changed in incompatible ways, possibly without notice, but not
 without a good reason.
 
 This class provides a tie interface for record array members.
 
-In the future a short cut for using this with L<FFI::Platypus::Record> 
+In the future a short cut for using this with L<FFI::Platypus::Record>
 directly may be provided.
 
 =head1 SEE ALSO
@@ -143,6 +143,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
