@@ -3,7 +3,7 @@ package FFI::Platypus::Type::PointerSizeBuffer;
 use strict;
 use warnings;
 use FFI::Platypus;
-use FFI::Platypus::API qw( 
+use FFI::Platypus::API qw(
   arguments_set_pointer
   arguments_set_uint32
   arguments_set_uint64
@@ -12,13 +12,13 @@ use FFI::Platypus::Buffer qw( scalar_to_buffer );
 use FFI::Platypus::Buffer qw( buffer_to_scalar );
 
 # ABSTRACT: Convert string scalar to a buffer as a pointer / size_t combination
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 my @stack;
 
-*arguments_set_size_t 
-  = FFI::Platypus->new->sizeof('size_t') == 4
+*arguments_set_size_t
+  = FFI::Platypus->new( api => 1 )->sizeof('size_t') == 4
   ? \&arguments_set_uint32
   : \&arguments_set_uint64;
 
@@ -60,7 +60,7 @@ FFI::Platypus::Type::PointerSizeBuffer - Convert string scalar to a buffer as a
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ In your Platypus::FFI code:
 
  use FFI::Platypus;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->load_custom_type('::PointerSizeBuffer' => 'buffer');
  
  $ffi->attach(function_with_buffer => ['buffer'] => 'void');
@@ -85,10 +85,10 @@ In your Platypus::FFI code:
 
 =head1 DESCRIPTION
 
-A common pattern in C code is to pass in a region of memory as a buffer, 
-consisting of a pointer and a size of the memory region.  In Perl, 
-string scalars also point to a contiguous series of bytes that has a 
-size, so when interfacing with C libraries it is handy to be able to 
+A common pattern in C code is to pass in a region of memory as a buffer,
+consisting of a pointer and a size of the memory region.  In Perl,
+string scalars also point to a contiguous series of bytes that has a
+size, so when interfacing with C libraries it is handy to be able to
 pass in a string scalar as a pointer / size buffer pair.
 
 =head1 SEE ALSO
@@ -131,6 +131,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
