@@ -8,10 +8,10 @@ use FFI::Probe::Runner;
 use FFI::Build;
 use FFI::Build::File::C;
 use Capture::Tiny qw( capture_merged capture );
-use File::Temp qw( tempdir );
+use FFI::Temp;
 
 # ABSTRACT: System detection and probing for FFI extensions.
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 sub new
@@ -49,7 +49,7 @@ sub new
     log           => $args{log},
     data_filename => $args{data_filename},
     data          => $data,
-    dir           => tempdir( CLEANUP => 1, TEMPLATE => 'ffi-probe-XXXXXX', DIR => '.' ),
+    dir           => FFI::Temp->newdir( TEMPLATE => 'ffi-probe-XXXXXX' ),
     counter       => 0,
     runner        => $args{runner},
     alien         => $args{alien} || [],
@@ -77,7 +77,7 @@ sub check_header
   $code .= "#include <$_>\n" for @{ $self->{headers} }, $header;
 
   my $build = FFI::Build->new("hcheck@{[ ++$self->{counter} ]}",
-    verbose => 1,
+    verbose => 2,
     dir     => $self->{dir},
     alien   => $self->{alien},
     cflags  => $self->{cflags},
@@ -112,7 +112,7 @@ sub check_cpp
   my($self, $code) = @_;
 
   my $build = FFI::Build->new("hcheck@{[ ++$self->{counter} ]}",
-    verbose => 1,
+    verbose => 2,
     dir     => $self->{dir},
     alien   => $self->{alien},
     cflags  => $self->{cflags},
@@ -169,11 +169,12 @@ sub check_eval
   $code =~ s/##EVAL##/$eval/;
 
   my $build = FFI::Build->new("eval@{[ ++$self->{counter} ]}",
-    verbose => 1,
+    verbose => 2,
     dir     => $self->{dir},
     alien   => $self->{alien},
     cflags  => $self->{cflags},
     libs    => $self->{libs},
+    export  => ['dlmain'],
   );
   $build->source(
     FFI::Build::File::C->new(
@@ -265,9 +266,9 @@ sub check_type_int
       "struct align { char a; $type b; };",
     ],
     eval => {
-      "type.$type.size"  => [ '%d' => "(int)sizeof($type)" ],
-      "type.$type.sign"  => [ '%s' => "signed($type)" ],
-      "type.$type.align" => [ '%d' => "(int)offsetof(struct align, b)" ],
+      "type.$type.size"  => [ '%d' => "(int)sizeof($type)"             ],
+      "type.$type.sign"  => [ '%s' => "signed($type)"                  ],
+      "type.$type.align" => [ '%d' => '(int)offsetof(struct align, b)' ],
     },
   );
 
@@ -280,6 +281,62 @@ sub check_type_int
 }
 
 
+sub check_type_enum
+{
+  my($self) = @_;
+
+  $self->check_header('stddef.h');
+
+  my $ret = $self->check_eval(
+    decl => [
+      '#define signed(type)  (((type)-1) < 0) ? "signed" : "unsigned"',
+      "typedef enum { ONE, TWO } myenum;",
+      "struct align { char a; myenum b; };",
+    ],
+    eval => {
+      "type.enum.size"  => [ '%d' => '(int)sizeof(myenum)'            ],
+      "type.enum.sign"  => [ '%s' => 'signed(myenum)'                 ],
+      "type.enum.align" => [ '%d' => '(int)offsetof(struct align, b)' ],
+    },
+  );
+
+  return unless $ret;
+
+  my $size = $self->data->{type}->{enum}->{size};
+  my $sign = $self->data->{type}->{enum}->{sign};
+
+  sprintf("%sint%d", $sign eq 'signed' ? 's' : 'u', $size*8);
+}
+
+
+sub check_type_signed_enum
+{
+  my($self) = @_;
+
+  $self->check_header('stddef.h');
+
+  my $ret = $self->check_eval(
+    decl => [
+      '#define signed(type)  (((type)-1) < 0) ? "signed" : "unsigned"',
+      "typedef enum { NEG = -1, ONE = 1, TWO = 2 } myenum;",
+      "struct align { char a; myenum b; };",
+    ],
+    eval => {
+      "type.senum.size"  => [ '%d' => '(int)sizeof(myenum)'            ],
+      "type.senum.sign"  => [ '%s' => 'signed(myenum)'                 ],
+      "type.senum.align" => [ '%d' => '(int)offsetof(struct align, b)' ],
+    },
+  );
+
+  return unless $ret;
+
+  my $size = $self->data->{type}->{senum}->{size};
+  my $sign = $self->data->{type}->{senum}->{sign};
+
+  sprintf("%sint%d", $sign eq 'signed' ? 's' : 'u', $size*8);
+}
+
+
 sub check_type_float
 {
   my($self, $type) = @_;
@@ -291,8 +348,8 @@ sub check_type_float
       "struct align { char a; $type b; };",
     ],
     eval => {
-      "type.$type.size"  => [ '%d' => "(int)sizeof($type)" ],
-      "type.$type.align" => [ '%d' => "(int)offsetof(struct align, b)" ],
+      "type.$type.size"  => [ '%d' => "(int)sizeof($type)"             ],
+      "type.$type.align" => [ '%d' => '(int)offsetof(struct align, b)' ],
     },
   );
 
@@ -330,8 +387,8 @@ sub check_type_pointer
       "struct align { char a; void* b; };",
     ],
     eval => {
-      "type.pointer.size"  => [ '%d' => "(int)sizeof(void *)" ],
-      "type.pointer.align" => [ '%d' => "(int)offsetof(struct align, b)" ],
+      "type.pointer.size"  => [ '%d' => '(int)sizeof(void *)'            ],
+      "type.pointer.align" => [ '%d' => '(int)offsetof(struct align, b)' ],
     },
   );
 
@@ -389,7 +446,7 @@ sub save
     ->Sortkeys(1)
     ->Dump;
 
-  mkpath( $dir, 0, 0755 ) unless -d $dir;
+  mkpath( $dir, 0, oct(755) ) unless -d $dir;
 
   my $fh;
   open($fh, '>', $self->{data_filename}) || die "error writing @{[ $self->{data_filename} ]}";
@@ -455,12 +512,12 @@ FFI::Probe - System detection and probing for FFI extensions.
 
 =head1 VERSION
 
-version 0.83
+version 1.10
 
 =head1 SYNOPSIS
 
  use FFI::Probe;
-
+ 
  my $probe = FFI::Probe->new;
  $probe->check_header('foo.h');
  ...
@@ -533,6 +590,14 @@ Any evaluations that should be returned.
 
  my $type = $probe->check_type_int($type);
 
+=head2 check_type_enum
+
+ my $type = $probe->check_type_enum;
+
+=head2 check_type_enum
+
+ my $type = $probe->check_type_enum;
+
 =head2 check_type_float
 
  my $type = $probe->check_type_float($type);
@@ -553,7 +618,7 @@ Used internally to store a value.
 
 Saves the values already detected.
 
-=head2
+=head2 data
 
  my $data = $probe->data;
 
@@ -604,6 +669,16 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
